<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Pelihat Imej Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versi:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>imej</translation>
    </message>
    <message>
        <source>images</source>
        <translation>imej</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>album</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Urus segerak</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Menyegerak:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Tanpa nama</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Diimport baru-baru ini</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kegemaran saya</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Anda pasti mahu padam album ini?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Undur</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kegemaran saya</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Garis Masa</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Anda boleh menambah direktori segerak atau seret dan lepaskan imej ke dalam garis masa</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Tanpa nama</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Pelihat Imej Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imej</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Anda pasti mahu tambah gambar ke dalam album?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Segerak dan Cipta</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Segerak</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Anda pasti mahu tambah ke dalam senarai segerak dan cipta album bernama selepas folder ini?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Berjaya dieksport</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Gagal dieksport</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Anda pasti mahu campak gambar ke dalam TONG SAMPAH?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Fail ini mengandungi halaman berbilang, sila guna Evince untuk melihat semua halaman.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin Penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Salin ke papan keratan</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Anda boleh tambah direktori segerak atau seret dan lepas imej ke dalam garis masa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambah ke album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambah ke album baharu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Buka Direktori</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Anda tiada keizinan untuk melihat imej</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nama </translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Tarikh ditangkap</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Tarikh diubahsuai</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Saiz fail</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Ruangwarna</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mod dedahan</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program dedahan</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Masa dedahan</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Denyar</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Bukaan</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Panjang fokus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Bukaan maks</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mod pemeteran</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Imbangan putih</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Pemampasan denyar</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model kanta</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Tiada penskalaan</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Suai muat halaman dengan imej</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Suai muat imej dengan halaman</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skala ke:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Sentimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inci</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Kedudukan Imej</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Penskalaan</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Tetapan Imej</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Bidaian</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Penukar</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Pelungsur</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Gelang</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Pilih Direktori</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Direktori ini dilumpuhkan untuk penyegerakan</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Tambah folder</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Pengurusan Direktori Segerak</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Senarai direktori kosong</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Batal segerak</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imej</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Peranti telah ditanggalkan</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Direktori ini tiada lagi wujud</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Mengira...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pelihatan Imej</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Tamat paparan</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Skrin terdahulu</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Skrin berikutnya</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Sila masukkan pintasan baharu</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Lihat Gambar</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Pulih Lalai</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Tamat paparan</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Tamat paparan</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Jeda/Main</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Tetapan Slaid</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Tukar kesan</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Jangkamasa</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Tukar jangkamasa</translation>
    </message>
    <message>
        <source>second</source>
        <translation>saat</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Undur</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Pengurusan imej</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kegemaran saya</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Saiz 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Suai muat dengan tetingkap</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Tiada fail imej ditemui</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Imej</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 imej</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 imej</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Urus segerak</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Menyegerak:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tambah</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Anda boleh tambah direktori segerak atau seret dan lepas imej ke dalam garis masa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambah ke album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambah ke album baharu</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Salin ke papan keratan</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Tetapan Slaid</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Kesan</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Jangkamasa</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>hh BBBB tttt</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kegemaran saya</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Diimport baru-baru ini</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Pelihat Imej Deepin merupakan pengurus imej yang berfesyen &amp; lancar.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Ia difiturkan dengan pengurusan imej, pemaparan imej dan penyuntingan imej asas.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema gelap</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Pelihat Imej Deepin merupakan pengurus imej dengan antaramuka berfesyen dan prestasi yang lancar.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Garis Masa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambah ke album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambah ke album baharu</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Keluar dari skrin penuh</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Salin ke papan keratan</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Tunjuk tetingkap navigasi</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Sembunyi tetingkap navigasi</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Imej</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Semua imej</translation>
    </message>
</context>
</TS>